"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsCognitoJwtAuth = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const checkJwt_1 = require("./checkJwt");
const unencryptPayload_1 = require("./unencryptPayload");
const digestCacheHash_1 = require("./digestCacheHash");
const description_1 = require("./description");
class AwsCognitoJwtAuth {
    constructor() {
        this.description = description_1.description;
    }
    async execute() {
        const userPoolId = this.getNodeParameter('userPoolId', 0);
        const awsRegion = this.getNodeParameter('awsRegion', 0);
        const ignoreExpiration = this.getNodeParameter('ignoreExpiration', 0);
        const accessToken = this.getNodeParameter('accessToken', 0, '');
        const staticData = this.getWorkflowStaticData('node');
        const cacheHash = (0, digestCacheHash_1.digestCacheHash)(userPoolId, awsRegion);
        const shouldFetchJwks = staticData.cacheHash !== cacheHash;
        console.log({ cacheHash, old: staticData.cacheHash, shouldFetchJwks });
        staticData.jwks = shouldFetchJwks
            ? await (0, unencryptPayload_1.fetchJwk)({ awsRegion, userPoolId }, this.helpers.httpRequest)
            : staticData.jwks;
        const jwks = staticData.jwks;
        try {
            const { json: { body: body }, } = this.getInputData(0)[0];
            const user = (0, checkJwt_1.extractUserFromJwt)({
                accessToken,
                jwks,
                ignoreExpiration,
            });
            staticData.cacheHash = cacheHash;
            return this.prepareOutputData([{ json: { user, body } }], 0);
        }
        catch (error) {
            return this.prepareOutputData([
                {
                    json: {},
                    error: new n8n_workflow_1.NodeOperationError(this.getNode(), error),
                },
            ], 1);
        }
    }
}
exports.AwsCognitoJwtAuth = AwsCognitoJwtAuth;
//# sourceMappingURL=AwsCognitoJwtAuth.node.js.map